| Title: | Lightweight Interface to TIGER/Line Shapefiles |
|---|---|
| Description: | Download geographic shapes from the United States Census Bureau TIGER/Line Shapefiles <https://www.census.gov/geographies/mapping-files/time-series/geo/tiger-line-file.html>. Functions support downloading and reading in geographic boundary data. All downloads can be set up with a cache to avoid multiple downloads. Data is available back to 2000 for most geographies. |
| Authors: | Christopher T. Kenny [aut, cre] (ORCID: <https://orcid.org/0000-0002-9386-6860>), Cory McCartan [aut] |
| Maintainer: | Christopher T. Kenny <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.11 |
| Built: | 2026-06-02 09:52:29 UTC |
| Source: | https://github.com/alarm-redist/tinytiger |
Contains three columns:
state: state FIPS
county: county FIPS
name: county name
data("county_fips_2020")data("county_fips_2020")
tibble
Download TIGER shapes for Address Ranges
tt_address_ranges(state, county, year = 2025)tt_address_ranges(state, county, year = 2025)
state |
FIPS, postal codes, or full names of states. |
county |
FIPS codes or full names of counties. Optional. |
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_address_ranges("DE", county = "001")) # downloads slow on CRAN# Wrapped in try due to false positive 304 errors try(tt_address_ranges("DE", county = "001")) # downloads slow on CRAN
Download TIGER shapes for American Indian / Alaska Native / Native Hawaiian Areas
tt_ai_an_nh_areas(year = 2025)tt_ai_an_nh_areas(year = 2025)
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_ai_an_nh_areas())# Wrapped in try due to false positive 304 errors try(tt_ai_an_nh_areas())
Download TIGER shapes for Alaska Native Regional Corporation (Alaska)
tt_anrc(year = 2025)tt_anrc(year = 2025)
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_anrc()) # downloads slow on CRAN# Wrapped in try due to false positive 304 errors try(tt_anrc()) # downloads slow on CRAN
Download TIGER shapes for Area Landmarks
tt_area_landmarks(state, year = 2025)tt_area_landmarks(state, year = 2025)
state |
FIPS, postal codes, or full names of states. |
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_area_landmarks("DE")) # downloads slow on CRAN# Wrapped in try due to false positive 304 errors try(tt_area_landmarks("DE")) # downloads slow on CRAN
Download TIGER Shapes for Area Water
tt_area_water(state, county, year = 2025)tt_area_water(state, county, year = 2025)
state |
FIPS, postal codes, or full names of states. |
county |
FIPS codes or full names of counties. Optional. |
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_area_water("DE")) # downloads slow on CRAN# Wrapped in try due to false positive 304 errors try(tt_area_water("DE")) # downloads slow on CRAN
Download TIGER shapes for block groups
tt_block_groups(state, county, year = 2025)tt_block_groups(state, county, year = 2025)
state |
FIPS, postal codes, or full names of states. |
county |
FIPS codes or full names of counties. Optional. |
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_block_groups(state = "DE", county = "001")) # downloads slow on CRAN# Wrapped in try due to false positive 304 errors try(tt_block_groups(state = "DE", county = "001")) # downloads slow on CRAN
Download TIGER shapes for blocks
tt_blocks(state, county, year = 2025)tt_blocks(state, county, year = 2025)
state |
FIPS, postal codes, or full names of states. |
county |
FIPS codes or full names of counties. Optional. |
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_blocks(state = "DE", county = "001"))# Wrapped in try due to false positive 304 errors try(tt_blocks(state = "DE", county = "001"))
tinytiger cacheFunctions to inspect and clear the cache. If the cache is not enabled, uses a temporary directory.
tt_cache_size() tt_cache_clear(force = FALSE) tt_cache_path()tt_cache_size() tt_cache_clear(force = FALSE) tt_cache_path()
force |
FALSE by default. Asks the user to confirm if interactive. Does not clear cache if force is FALSE and not interactive. |
For tt_cache_size(), tthe size in bytes, invisbly
For tt_cache_clear(), the path to the cache, invisbly.
For tt_cache_path(), the path to the cache
tt_cache_size() tt_cache_clear() tt_cache_path()tt_cache_size() tt_cache_clear() tt_cache_path()
Download TIGER shapes for Core Based Statistical Areas
tt_cbsa(year = 2021)tt_cbsa(year = 2021)
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# takes > 5 seconds # Wrapped in try due to false positive 304 errors try(tt_cbsa()) # downloads slow on CRAN# takes > 5 seconds # Wrapped in try due to false positive 304 errors try(tt_cbsa()) # downloads slow on CRAN
Download TIGER shapes for Coastlines
tt_coastline(year = 2025)tt_coastline(year = 2025)
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# takes > 5 seconds # Wrapped in try due to false positive 304 errors try(tt_coastline()) # downloads slow on CRAN# takes > 5 seconds # Wrapped in try due to false positive 304 errors try(tt_coastline()) # downloads slow on CRAN
Download TIGER shapes for congressional districts
tt_congressional_districts(state, year = 2025)tt_congressional_districts(state, year = 2025)
state |
FIPS, postal codes, or full names of states. |
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# takes > 5 seconds # Wrapped in try due to false positive 304 errors try(tt_congressional_districts()) # downloads slow on CRAN# takes > 5 seconds # Wrapped in try due to false positive 304 errors try(tt_congressional_districts()) # downloads slow on CRAN
Download TIGER shapes for Public Use Microdata Areas
tt_consolidated_cities(state, year = 2025)tt_consolidated_cities(state, year = 2025)
state |
FIPS, postal codes, or full names of states. |
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_consolidated_cities("CT")) # downloads slow on CRAN# Wrapped in try due to false positive 304 errors try(tt_consolidated_cities("CT")) # downloads slow on CRAN
Download TIGER shapes for counties
tt_counties(state, year = 2025)tt_counties(state, year = 2025)
state |
FIPS, postal codes, or full names of states. |
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# takes > 5 seconds # Wrapped in try due to false positive 304 errors try(tt_counties(state = "DE")) # downloads slow on CRAN# takes > 5 seconds # Wrapped in try due to false positive 304 errors try(tt_counties(state = "DE")) # downloads slow on CRAN
Download TIGER shapes for County Subdivisions
tt_county_subdivisions(state, year = 2025)tt_county_subdivisions(state, year = 2025)
state |
FIPS, postal codes, or full names of states. |
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_county_subdivisions("DE")) # downloads slow on CRAN# Wrapped in try due to false positive 304 errors try(tt_county_subdivisions("DE")) # downloads slow on CRAN
Download TIGER shapes for Combined Statistical Area
tt_csa(year = 2021)tt_csa(year = 2021)
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_csa())# Wrapped in try due to false positive 304 errors try(tt_csa())
Download TIGER shapes for Elementary School Districts
tt_elementary_school_districts(state, year = 2025)tt_elementary_school_districts(state, year = 2025)
state |
FIPS, postal codes, or full names of states. |
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_elementary_school_districts("AZ")) # downloads slow on CRAN# Wrapped in try due to false positive 304 errors try(tt_elementary_school_districts("AZ")) # downloads slow on CRAN
Download TIGER shapes for Estates (US Virgin Islands)
tt_estates(year = 2025)tt_estates(year = 2025)
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_estates()) # downloads slow on CRAN# Wrapped in try due to false positive 304 errors try(tt_estates()) # downloads slow on CRAN
Download TIGER Shapes for Linear Water
tt_linear_water(state, county, year = 2025)tt_linear_water(state, county, year = 2025)
state |
FIPS, postal codes, or full names of states. |
county |
FIPS codes or full names of counties. Optional. |
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_linear_water("DE")) # downloads slow on CRAN# Wrapped in try due to false positive 304 errors try(tt_linear_water("DE")) # downloads slow on CRAN
Download TIGER shapes for Metropolitan Divisions
tt_metropolitan_divisions(year = 2021)tt_metropolitan_divisions(year = 2021)
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_metropolitan_divisions()) # downloads slow on CRAN# Wrapped in try due to false positive 304 errors try(tt_metropolitan_divisions()) # downloads slow on CRAN
Download TIGER shapes for Military Installations
tt_military(year = 2025)tt_military(year = 2025)
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_military()) # downloads slow on CRAN# Wrapped in try due to false positive 304 errors try(tt_military()) # downloads slow on CRAN
Download TIGER shapes for New England City and Town Area
tt_new_england_cities(year = 2025)tt_new_england_cities(year = 2025)
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_new_england_cities()) # downloads slow on CRAN# Wrapped in try due to false positive 304 errors try(tt_new_england_cities()) # downloads slow on CRAN
Download TIGER shapes for New England City and Town Area Divisions
tt_new_england_city_divisions(year = 2021)tt_new_england_city_divisions(year = 2021)
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_new_england_city_divisions()) # downloads slow on CRAN# Wrapped in try due to false positive 304 errors try(tt_new_england_city_divisions()) # downloads slow on CRAN
Download TIGER shapes for New England Combined City and Town Areas
tt_new_england_combined_areas(year = 2021)tt_new_england_combined_areas(year = 2021)
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_new_england_combined_areas()) # downloads slow on CRAN# Wrapped in try due to false positive 304 errors try(tt_new_england_combined_areas()) # downloads slow on CRAN
Download TIGER shapes for Places
tt_places(state, year = 2025)tt_places(state, year = 2025)
state |
FIPS, postal codes, or full names of states. |
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_places("DE")) # downloads slow on CRAN# Wrapped in try due to false positive 304 errors try(tt_places("DE")) # downloads slow on CRAN
Download TIGER shapes for Point Landmarks
tt_point_landmarks(state, year = 2025)tt_point_landmarks(state, year = 2025)
state |
FIPS, postal codes, or full names of states. |
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_point_landmarks("DE")) # downloads slow on CRAN# Wrapped in try due to false positive 304 errors try(tt_point_landmarks("DE")) # downloads slow on CRAN
Download TIGER shapes for Polygon Edges
tt_polygon_edges(state, county, year = 2025)tt_polygon_edges(state, county, year = 2025)
state |
FIPS, postal codes, or full names of states. |
county |
FIPS codes or full names of counties. Optional. |
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_polygon_edges("DE", county = "001")) # downloads slow on CRAN# Wrapped in try due to false positive 304 errors try(tt_polygon_edges("DE", county = "001")) # downloads slow on CRAN
Download TIGER shapes for Polygon Faces
tt_polygon_faces(state, county, year = 2025)tt_polygon_faces(state, county, year = 2025)
state |
FIPS, postal codes, or full names of states. |
county |
FIPS codes or full names of counties. Optional. |
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_polygon_faces("DE", county = "001")) # downloads slow on CRAN# Wrapped in try due to false positive 304 errors try(tt_polygon_faces("DE", county = "001")) # downloads slow on CRAN
Download TIGER shapes for Primary Roads
tt_primary_roads(year = 2025)tt_primary_roads(year = 2025)
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# takes > 5 seconds # Wrapped in try due to false positive 304 errors try(tt_primary_roads()) # downloads slow on CRAN# takes > 5 seconds # Wrapped in try due to false positive 304 errors try(tt_primary_roads()) # downloads slow on CRAN
Download TIGER shapes for Primary and Secondary Roads
tt_primary_secondary_roads(state, year = 2025)tt_primary_secondary_roads(state, year = 2025)
state |
FIPS, postal codes, or full names of states. |
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_primary_secondary_roads("DE")) # downloads slow on CRAN# Wrapped in try due to false positive 304 errors try(tt_primary_secondary_roads("DE")) # downloads slow on CRAN
Download TIGER shapes for Public Use Microdata Areas
tt_puma(state, year = 2025)tt_puma(state, year = 2025)
state |
FIPS, postal codes, or full names of states. |
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_puma("DE")) # downloads slow on CRAN# Wrapped in try due to false positive 304 errors try(tt_puma("DE")) # downloads slow on CRAN
Download TIGER shapes for Rails
tt_rails(year = 2025)tt_rails(year = 2025)
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# takes > 5 seconds # Wrapped in try due to false positive 304 errors try(tt_rails()) # downloads slow on CRAN# takes > 5 seconds # Wrapped in try due to false positive 304 errors try(tt_rails()) # downloads slow on CRAN
Download TIGER shapes for Roads
tt_roads(state, county, year = 2025)tt_roads(state, county, year = 2025)
state |
FIPS, postal codes, or full names of states. |
county |
FIPS codes or full names of counties. Optional. |
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_roads("DE")) # downloads slow on CRAN# Wrapped in try due to false positive 304 errors try(tt_roads("DE")) # downloads slow on CRAN
Download TIGER shapes for Secondary School Districts
tt_secondary_school_districts(state, year = 2025)tt_secondary_school_districts(state, year = 2025)
state |
FIPS, postal codes, or full names of states. |
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_secondary_school_districts("AZ")) # downloads slow on CRAN# Wrapped in try due to false positive 304 errors try(tt_secondary_school_districts("AZ")) # downloads slow on CRAN
Download TIGER shapes for lower state legislative districts
tt_state_leg_lower(state, year = 2025)tt_state_leg_lower(state, year = 2025)
state |
FIPS, postal codes, or full names of states. |
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_state_leg_lower("DE")) # downloads slow on CRAN# Wrapped in try due to false positive 304 errors try(tt_state_leg_lower("DE")) # downloads slow on CRAN
Download TIGER shapes for upper state legislative districts
tt_state_leg_upper(state, year = 2025)tt_state_leg_upper(state, year = 2025)
state |
FIPS, postal codes, or full names of states. |
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_state_leg_lower("DE")) # downloads slow on CRAN# Wrapped in try due to false positive 304 errors try(tt_state_leg_lower("DE")) # downloads slow on CRAN
Download TIGER shapes for states
tt_states(year = 2025)tt_states(year = 2025)
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_states())# Wrapped in try due to false positive 304 errors try(tt_states())
Download TIGER shapes for Subbarrios (Puerto Rico)
tt_subbarrios(year = 2025)tt_subbarrios(year = 2025)
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_subbarrios()) # downloads slow on CRAN# Wrapped in try due to false positive 304 errors try(tt_subbarrios()) # downloads slow on CRAN
Download TIGER shapes for tracts
tt_tracts(state, county, year = 2025)tt_tracts(state, county, year = 2025)
state |
FIPS, postal codes, or full names of states. |
county |
FIPS codes or full names of counties. Optional. |
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_tracts(state = "DE", county = "001")) # downloads slow on CRAN# Wrapped in try due to false positive 304 errors try(tt_tracts(state = "DE", county = "001")) # downloads slow on CRAN
Download TIGER shapes for Tribal Block Groups
tt_tribal_block_groups(year = 2025)tt_tribal_block_groups(year = 2025)
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_tribal_block_groups())# Wrapped in try due to false positive 304 errors try(tt_tribal_block_groups())
Download TIGER shapes for American Indian Tribal Subdivision National
tt_tribal_subdivisions(year = 2025)tt_tribal_subdivisions(year = 2025)
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_tribal_subdivisions())# Wrapped in try due to false positive 304 errors try(tt_tribal_subdivisions())
Download TIGER shapes for Tribal Tracts
tt_tribal_tracts(year = 2025)tt_tribal_tracts(year = 2025)
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_tribal_tracts())# Wrapped in try due to false positive 304 errors try(tt_tribal_tracts())
Download TIGER shapes for Urban Area
tt_uac(year = 2025)tt_uac(year = 2025)
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# takes > 5 seconds # Wrapped in try due to false positive 304 errors try(tt_uac()) # downloads slow on CRAN# takes > 5 seconds # Wrapped in try due to false positive 304 errors try(tt_uac()) # downloads slow on CRAN
Download TIGER shapes for Unified School Districts
tt_unified_school_districts(state, year = 2025)tt_unified_school_districts(state, year = 2025)
state |
FIPS, postal codes, or full names of states. |
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_unified_school_districts("DE")) # downloads slow on CRAN# Wrapped in try due to false positive 304 errors try(tt_unified_school_districts("DE")) # downloads slow on CRAN
Download TIGER shapes for Voting Districts
tt_voting_districts(state, county, year = 2025)tt_voting_districts(state, county, year = 2025)
state |
FIPS, postal codes, or full names of states. |
county |
FIPS codes or full names of counties. Optional. |
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# Wrapped in try due to false positive 304 errors try(tt_voting_districts("DE", county = "001")) # downloads slow on CRAN# Wrapped in try due to false positive 304 errors try(tt_voting_districts("DE", county = "001")) # downloads slow on CRAN
Download TIGER shapes for Zip Code Tabulation Areas
tt_zcta(year = 2025)tt_zcta(year = 2025)
year |
Integer year. Required. 2000 and 2010-2025 are currently supported. |
sf data.frame
# takes > 5 seconds # Wrapped in try due to false positive 304 errors try(tt_zcta()) # downloads slow on CRAN# takes > 5 seconds # Wrapped in try due to false positive 304 errors try(tt_zcta()) # downloads slow on CRAN